@@ -30,7 +30,7 @@ SEXP SISe_run(SEXP, SEXP, SEXP);
 SEXP SISe3_run(SEXP, SEXP, SEXP);
 SEXP SISe3_sp_run(SEXP, SEXP, SEXP);
 SEXP SISe_sp_run(SEXP, SEXP, SEXP);
-SEXP siminf_ldata_sp(SEXP, SEXP, SEXP);
+SEXP SimInf_ldata_sp(SEXP, SEXP, SEXP);
 
 /**
  * Is OpenMP available
@@ -57,7 +57,7 @@ static const R_CallMethodDef callMethods[] =
     CALLDEF(SISe3_sp_run, 3),
     CALLDEF(SISe_sp_run, 3),
     CALLDEF(SimInf_have_openmp, 0),
-    CALLDEF(siminf_ldata_sp, 3),
+    CALLDEF(SimInf_ldata_sp, 3),
     {NULL, NULL, 0}
 };
 
