@@ -19,7 +19,7 @@
  */
 
 #include "SimInf.h"
-#include "siminf_forward_euler_linear_decay.h"
+#include "SimInf_forward_euler_linear_decay.h"
 
 /* Offset in integer compartment state vector */
 enum {S_1, I_1, S_2, I_2, S_3, I_3};
@@ -186,7 +186,7 @@ int SISe3_post_time_step(
 
     /* Time dependent beta in each of the four intervals of the
      * year. Forward Euler step. */
-    v_new[PHI] = siminf_forward_euler_linear_decay(
+    v_new[PHI] = SimInf_forward_euler_linear_decay(
         phi, day,
         ldata[END_T1], ldata[END_T2], ldata[END_T3], ldata[END_T4],
         gdata[BETA_T1], gdata[BETA_T2], gdata[BETA_T3], gdata[BETA_T4]);
