@@ -1,6 +1,6 @@
 ## SimInf, a framework for stochastic disease spread simulations
-## Copyright (C) 2015 - 2016  Stefan Engblom
-## Copyright (C) 2015 - 2016  Stefan Widgren
+## Copyright (C) 2015 - 2017  Stefan Engblom
+## Copyright (C) 2015 - 2017  Stefan Widgren
 ##
 ## This program is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -70,62 +70,62 @@ res <- tools::assertError(distance_matrix(1:10, 1:10, 3, -1))
 stopifnot(length(grep("Invalid 'min_dist' argument. Please provide 'min_dist' > 0.",
                       res[[1]]$message)) > 0)
 
-## Check 'data' argument to C function 'siminf_ldata_sp'
+## Check 'data' argument to C function 'SimInf_ldata_sp'
 res <- tools::assertError(
-    .Call("siminf_ldata_sp", NULL, d, 0L, PACKAGE = "SimInf"))
+    .Call("SimInf_ldata_sp", NULL, d, 0L, PACKAGE = "SimInf"))
 stopifnot(length(grep("Invalid 'data' argument",
                       res[[1]]$message)) > 0)
 
 res <- tools::assertError(
-    .Call("siminf_ldata_sp", d, d, 0L, PACKAGE = "SimInf"))
+    .Call("SimInf_ldata_sp", d, d, 0L, PACKAGE = "SimInf"))
 stopifnot(length(grep("Invalid 'data' argument",
                       res[[1]]$message)) > 0)
 
 res <- tools::assertError(
-    .Call("siminf_ldata_sp", 1:10, d, 0L, PACKAGE = "SimInf"))
+    .Call("SimInf_ldata_sp", 1:10, d, 0L, PACKAGE = "SimInf"))
 stopifnot(length(grep("Invalid 'data' argument",
                       res[[1]]$message)) > 0)
 
-## Check 'distance' argument to C function 'siminf_ldata_sp'
+## Check 'distance' argument to C function 'SimInf_ldata_sp'
 res <- tools::assertError(
-    .Call("siminf_ldata_sp", l, NULL, 0L, PACKAGE = "SimInf"))
+    .Call("SimInf_ldata_sp", l, NULL, 0L, PACKAGE = "SimInf"))
 stopifnot(length(grep("Invalid 'distance' argument",
                       res[[1]]$message)) > 0)
 
 res <- tools::assertError(
-    .Call("siminf_ldata_sp", l, l, 0L, PACKAGE = "SimInf"))
+    .Call("SimInf_ldata_sp", l, l, 0L, PACKAGE = "SimInf"))
 stopifnot(length(grep("Invalid 'distance' argument",
                       res[[1]]$message)) > 0)
 
 res <- tools::assertError(
-    .Call("siminf_ldata_sp", l, Matrix::Diagonal(10), 0L, PACKAGE = "SimInf"))
+    .Call("SimInf_ldata_sp", l, Matrix::Diagonal(10), 0L, PACKAGE = "SimInf"))
 stopifnot(length(grep("Invalid 'distance' argument",
                       res[[1]]$message)) > 0)
 
-## Check 'metric' argument to C function 'siminf_ldata_sp'
+## Check 'metric' argument to C function 'SimInf_ldata_sp'
 res <- tools::assertError(
-    .Call("siminf_ldata_sp", l, d, NA_integer_, PACKAGE = "SimInf"))
+    .Call("SimInf_ldata_sp", l, d, NA_integer_, PACKAGE = "SimInf"))
 stopifnot(length(grep("Invalid 'metric' argument",
                       res[[1]]$message)) > 0)
 
 res <- tools::assertError(
-    .Call("siminf_ldata_sp", l, d, NULL, PACKAGE = "SimInf"))
+    .Call("SimInf_ldata_sp", l, d, NULL, PACKAGE = "SimInf"))
 stopifnot(length(grep("Invalid 'metric' argument",
                       res[[1]]$message)) > 0)
 
 res <- tools::assertError(
-    .Call("siminf_ldata_sp", l, d, 0.0, PACKAGE = "SimInf"))
+    .Call("SimInf_ldata_sp", l, d, 0.0, PACKAGE = "SimInf"))
 stopifnot(length(grep("Invalid 'metric' argument",
                       res[[1]]$message)) > 0)
 
 res <- tools::assertError(
-    .Call("siminf_ldata_sp", l, d, c(0L, 0L), PACKAGE = "SimInf"))
+    .Call("SimInf_ldata_sp", l, d, c(0L, 0L), PACKAGE = "SimInf"))
 stopifnot(length(grep("Invalid 'metric' argument",
                       res[[1]]$message)) > 0)
 
 ## Check non-equal number of nodes in 'distance' and 'data'
 res <- tools::assertError(
-    .Call("siminf_ldata_sp", l[, -1], d, 0L, PACKAGE = "SimInf"))
+    .Call("SimInf_ldata_sp", l[, -1], d, 0L, PACKAGE = "SimInf"))
 stopifnot(length(grep("The number of nodes in 'data' and 'distance' are not equal",
                       res[[1]]$message)) > 0)
 
@@ -141,7 +141,7 @@ ldata_exp <- structure(c(91, 182, 273, 365, 1, 3, 2, 4, -1, 0, 0, 0, 0, 0,
                          91, 182, 273, 365, 6, 4, 7, 4, 9, 2, -1, 0, 0, 0,
                          91, 182, 273, 365, 7, 4, 8, 3, -1, 0, 0, 0, 0, 0),
                        .Dim = c(14L, 10L))
-ldata_obs <- .Call("siminf_ldata_sp", l, d, 0L, PACKAGE = "SimInf")
+ldata_obs <- .Call("SimInf_ldata_sp", l, d, 0L, PACKAGE = "SimInf")
 stopifnot(all(abs(ldata_obs - ldata_exp) < tol))
 
 ## Check 'ldata' with metric equal to distance
@@ -173,7 +173,7 @@ ldata_exp <- structure(c(91, 182, 273, 365, 1, 1.4142135623731,
                          91, 182, 273, 365, 7, 2.82842712474619,
                          8, 1.4142135623731, -1, 0, 0, 0, 0, 0),
                        .Dim = c(14L, 10L))
-ldata_obs <- .Call("siminf_ldata_sp", l, d, 1L, PACKAGE = "SimInf")
+ldata_obs <- .Call("SimInf_ldata_sp", l, d, 1L, PACKAGE = "SimInf")
 stopifnot(all(abs(ldata_obs - ldata_exp) < tol))
 
 ## Check 'ldata' with metric equal to 1 / distance^2
@@ -197,7 +197,7 @@ ldata_exp <- structure(c(91, 182, 273, 365, 1, 0.499999999999996, 2, 0.125,
                          0, 91, 182, 273, 365, 7, 0.125, 8, 0.499999999999996,
                          -1, 0, 0, 0, 0, 0), .Dim = c(14L, 10L))
 
-ldata_obs <- .Call("siminf_ldata_sp", l, d, 2L, PACKAGE = "SimInf")
+ldata_obs <- .Call("SimInf_ldata_sp", l, d, 2L, PACKAGE = "SimInf")
 stopifnot(all(abs(ldata_obs - ldata_exp) < tol))
 
 ## Check identical coordinates
